@@ -15,7 +15,7 @@ use constant FALSE                       => 0;
 
 Readonly::Scalar my $SEPARATOR => ';';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub new {
     my $class = shift;
@@ -60,20 +60,29 @@ sub postal_data {
 }
 
 sub get_all_postalcodes {
-    my ($self, $parameter_data) = @_;
+    my $self = shift;
+
     my @postalcodes = ();
 
-    if ( not $parameter_data ) {
-        $parameter_data = $self->postal_data;
-    }
-
-    foreach my $line ( @{$parameter_data} ) {
+    foreach my $line ( @{$self->postal_data} ) {
         $self->_retrieve_postalcode( \@postalcodes, $line );
     }
 
     return \@postalcodes;
 }
 
+sub get_all_cities {
+    my ($self) = @_;
+
+    my @cities = ();
+
+    foreach my $line ( @{$self->postal_data} ) {
+        $self->_retrieve_city( \@cities, $line );
+    }
+
+    return \@cities;
+}
+
 sub _retrieve_postalcode {
     my ( $self, $postalcodes, $string ) = @_;
 
@@ -95,6 +104,27 @@ sub _retrieve_postalcode {
     return;
 }
 
+sub _retrieve_city {
+    my ( $self, $postalcodes, $string ) = @_;
+
+    ## no critic qw(RegularExpressions::RequireLineBoundaryMatching RegularExpressions::RequireExtendedFormatting RegularExpressions::RequireDotMatchAnything)
+    my @entries = split /$SEPARATOR/x, $string, NUM_OF_DATA_ELEMENTS;
+
+    my $num_of_digits_in_postalcode = $self->num_of_digits_in_postalcode();
+
+    if ($entries[0] =~ m{
+        ^ #beginning of string
+        \d{$num_of_digits_in_postalcode} #digits in postalcode
+        $ #end of string
+        }xsm
+        )
+    {
+        push @{$postalcodes}, $entries[1];
+    }
+
+    return;
+}
+
 sub validate {
     my ($self, $number) = @_;
 
